@@ -48,13 +48,17 @@
 #define paramErr -50
 
 #ifndef errSSLServerAuthCompleted
-#define errSSLServerAuthCompleted -9841
+#  define errSSLServerAuthCompleted -9841
 #endif
 
 namespace {
 #if !defined(__MAC_10_8)
-static const SSLProtocol kTLSProtocol11 = (SSLProtocol)(kSSLProtocolAll + 1);
-static const SSLProtocol kTLSProtocol12 = (SSLProtocol)(kSSLProtocolAll + 2);
+static const SSLProtocol kTLSProtocol11 = (SSLProtocol)7;
+static const SSLProtocol kTLSProtocol12 = (SSLProtocol)8;
+#endif
+
+#if !defined(__MAC_10_13)
+static const SSLProtocol kTLSProtocol13 = (SSLProtocol)10;
 #endif
 
 #ifndef CIPHER_NO_DHPARAM
@@ -92,6 +96,8 @@ static inline const char* protoToString(SSLProtocol proto)
     return "TLSv1.1";
   case kTLSProtocol12:
     return "TLSv1.2";
+  case kTLSProtocol13:
+    return "TLSv1.3";
   default:
     return "Unknown";
   }
@@ -107,7 +113,8 @@ static struct {
 } kSuites[] = {
     // From CipherSuite.h (10.11)
     SUITE(SSL_NULL_WITH_NULL_NULL, 0x0000),
-    SUITE(SSL_RSA_WITH_NULL_MD5, 0x0001), SUITE(SSL_RSA_WITH_NULL_SHA, 0x0002),
+    SUITE(SSL_RSA_WITH_NULL_MD5, 0x0001),
+    SUITE(SSL_RSA_WITH_NULL_SHA, 0x0002),
     SUITE(SSL_RSA_EXPORT_WITH_RC4_40_MD5, 0x0003),
     SUITE(SSL_RSA_WITH_RC4_128_MD5, 0x0004),
     SUITE(SSL_RSA_WITH_RC4_128_SHA, 0x0005),
@@ -172,8 +179,12 @@ static struct {
     SUITE(TLS_ECDH_anon_WITH_3DES_EDE_CBC_SHA, 0xC017),
     SUITE(TLS_ECDH_anon_WITH_AES_128_CBC_SHA, 0xC018),
     SUITE(TLS_ECDH_anon_WITH_AES_256_CBC_SHA, 0xC019),
+    SUITE(TLS_ECDHE_PSK_WITH_AES_128_CBC_SHA, 0xC035),
+    SUITE(TLS_ECDHE_PSK_WITH_AES_256_CBC_SHA, 0xC036),
+    SUITE(TLS_PSK_WITH_CHACHA20_POLY1305_SHA256, 0xCCAB),
     SUITE(TLS_NULL_WITH_NULL_NULL, 0x0000),
-    SUITE(TLS_RSA_WITH_NULL_MD5, 0x0001), SUITE(TLS_RSA_WITH_NULL_SHA, 0x0002),
+    SUITE(TLS_RSA_WITH_NULL_MD5, 0x0001),
+    SUITE(TLS_RSA_WITH_NULL_SHA, 0x0002),
     SUITE(TLS_RSA_WITH_RC4_128_MD5, 0x0004),
     SUITE(TLS_RSA_WITH_RC4_128_SHA, 0x0005),
     SUITE(TLS_RSA_WITH_3DES_EDE_CBC_SHA, 0x000A),
@@ -253,6 +264,11 @@ static struct {
     SUITE(TLS_RSA_PSK_WITH_AES_256_CBC_SHA384, 0x00B7),
     SUITE(TLS_RSA_PSK_WITH_NULL_SHA256, 0x00B8),
     SUITE(TLS_RSA_PSK_WITH_NULL_SHA384, 0x00B9),
+    SUITE(TLS_AES_128_GCM_SHA256, 0x1301),
+    SUITE(TLS_AES_256_GCM_SHA384, 0x1302),
+    SUITE(TLS_CHACHA20_POLY1305_SHA256, 0x1303),
+    SUITE(TLS_AES_128_CCM_SHA256, 0x1304),
+    SUITE(TLS_AES_128_CCM_8_SHA256, 0x1305),
     SUITE(TLS_ECDHE_ECDSA_WITH_AES_128_CBC_SHA256, 0xC023),
     SUITE(TLS_ECDHE_ECDSA_WITH_AES_256_CBC_SHA384, 0xC024),
     SUITE(TLS_ECDH_ECDSA_WITH_AES_128_CBC_SHA256, 0xC025),
@@ -269,7 +285,8 @@ static struct {
     SUITE(TLS_ECDHE_RSA_WITH_AES_256_GCM_SHA384, 0xC030),
     SUITE(TLS_ECDH_RSA_WITH_AES_128_GCM_SHA256, 0xC031),
     SUITE(TLS_ECDH_RSA_WITH_AES_256_GCM_SHA384, 0xC032),
-    SUITE(TLS_EMPTY_RENEGOTIATION_INFO_SCSV, 0x00FF),
+    SUITE(TLS_ECDHE_RSA_WITH_CHACHA20_POLY1305_SHA256, 0xCCA8),
+    SUITE(TLS_ECDHE_ECDSA_WITH_CHACHA20_POLY1305_SHA256, 0xCCA9),
     SUITE(SSL_RSA_WITH_RC2_CBC_MD5, 0xFF80),
     SUITE(SSL_RSA_WITH_IDEA_CBC_MD5, 0xFF81),
     SUITE(SSL_RSA_WITH_DES_CBC_MD5, 0xFF82),
@@ -374,35 +391,29 @@ AppleTLSSession::AppleTLSSession(AppleTLSContext* ctx)
 
 #if defined(__MAC_10_8)
   switch (ctx->getMinTLSVersion()) {
-  case TLS_PROTO_SSL3:
-    (void)SSLSetProtocolVersionMin(sslCtx_, kSSLProtocol3);
-    break;
-  case TLS_PROTO_TLS10:
-    (void)SSLSetProtocolVersionMin(sslCtx_, kTLSProtocol1);
-    break;
   case TLS_PROTO_TLS11:
     (void)SSLSetProtocolVersionMin(sslCtx_, kTLSProtocol11);
     break;
   case TLS_PROTO_TLS12:
     (void)SSLSetProtocolVersionMin(sslCtx_, kTLSProtocol12);
     break;
+  case TLS_PROTO_TLS13:
+    (void)SSLSetProtocolVersionMin(sslCtx_, kTLSProtocol13);
+    break;
   default:
     break;
   }
 #else
   (void)SSLSetProtocolVersionEnabled(sslCtx_, kSSLProtocolAll, false);
   switch (ctx->getMinTLSVersion()) {
-  case TLS_PROTO_SSL3:
-    (void)SSLSetProtocolVersionEnabled(sslCtx_, kSSLProtocol3, true);
-  // fall through
-  case TLS_PROTO_TLS10:
-    (void)SSLSetProtocolVersionEnabled(sslCtx_, kTLSProtocol1, true);
-  // fall through
   case TLS_PROTO_TLS11:
     (void)SSLSetProtocolVersionEnabled(sslCtx_, kTLSProtocol11, true);
   // fall through
   case TLS_PROTO_TLS12:
     (void)SSLSetProtocolVersionEnabled(sslCtx_, kTLSProtocol12, true);
+  // fall through
+  case TLS_PROTO_TLS13:
+    (void)SSLSetProtocolVersionEnabled(sslCtx_, kTLSProtocol13, true);
   default:
     break;
   }
@@ -439,7 +450,7 @@ AppleTLSSession::AppleTLSSession(AppleTLSContext* ctx)
     return;
   }
   for (const auto& suite : enabled) {
-    A2_LOG_INFO(
+    A2_LOG_DEBUG(
         fmt("AppleTLS: Enabled suite %s", suiteToString(suite).c_str()));
   }
   if (SSLSetEnabledCiphers(sslCtx_, &enabled[0], enabled.size()) != noErr) {
@@ -553,7 +564,7 @@ int AppleTLSSession::closeConnection()
 
 int AppleTLSSession::checkDirection()
 {
-  // See: https://github.com/tatsuhiro-t/aria2/pull/61#issuecomment-16051793
+  // See: https://github.com/aria2/aria2/pull/61#issuecomment-16051793
   if (state_ == st_connected) {
     // Need to check read first, as SocketCore kinda expects this
     size_t buffered;
@@ -746,18 +757,15 @@ int AppleTLSSession::tlsConnect(const std::string& hostname,
                   protoToString(proto), suiteToString(suite).c_str()));
 
   switch (proto) {
-  case kSSLProtocol3:
-    version = TLS_PROTO_SSL3;
-    break;
-  case kTLSProtocol1:
-    version = TLS_PROTO_TLS10;
-    break;
   case kTLSProtocol11:
     version = TLS_PROTO_TLS11;
     break;
   case kTLSProtocol12:
     version = TLS_PROTO_TLS12;
     break;
+  case kTLSProtocol13:
+    version = TLS_PROTO_TLS13;
+    break;
   default:
     version = TLS_PROTO_NONE;
     break;
