@@ -35,32 +35,56 @@
 #include "BtAllowedFastMessage.h"
 #include "DlAbortEx.h"
 #include "Peer.h"
-#include "StringFormat.h"
+#include "fmt.h"
+#include "SocketBuffer.h"
 
 namespace aria2 {
 
-const std::string BtAllowedFastMessage::NAME("allowed fast");
+const char BtAllowedFastMessage::NAME[] = "allowed fast";
 
-SharedHandle<BtAllowedFastMessage> BtAllowedFastMessage::create
-(const unsigned char* data, size_t dataLength)
+BtAllowedFastMessage::BtAllowedFastMessage(size_t index)
+    : IndexBtMessage(ID, NAME, index)
+{
+}
+
+std::unique_ptr<BtAllowedFastMessage>
+BtAllowedFastMessage::create(const unsigned char* data, size_t dataLength)
 {
   return IndexBtMessage::create<BtAllowedFastMessage>(data, dataLength);
 }
 
-void BtAllowedFastMessage::doReceivedAction() {
-  if(!peer->isFastExtensionEnabled()) {
-    throw DL_ABORT_EX
-      (StringFormat("%s received while fast extension is disabled",
-                    toString().c_str()).str());
+void BtAllowedFastMessage::doReceivedAction()
+{
+  if (!getPeer()->isFastExtensionEnabled()) {
+    throw DL_ABORT_EX(fmt("%s received while fast extension is disabled",
+                          toString().c_str()));
   }
-  if(_metadataGetMode) {
+  if (isMetadataGetMode()) {
     return;
   }
-  peer->addPeerAllowedIndex(getIndex());
+  getPeer()->addPeerAllowedIndex(getIndex());
 }
 
-void BtAllowedFastMessage::onSendComplete() {
-  peer->addAmAllowedIndex(getIndex());
+namespace {
+struct ThisProgressUpdate : public ProgressUpdate {
+  ThisProgressUpdate(std::shared_ptr<Peer> peer, size_t index)
+      : peer(std::move(peer)), index(index)
+  {
+  }
+  virtual void update(size_t length, bool complete) CXX11_OVERRIDE
+  {
+    if (complete) {
+      peer->addAmAllowedIndex(index);
+    }
+  }
+  std::shared_ptr<Peer> peer;
+  size_t index;
+};
+} // namespace
+
+std::unique_ptr<ProgressUpdate> BtAllowedFastMessage::getProgressUpdate()
+{
+  return make_unique<ThisProgressUpdate>(getPeer(), getIndex());
 }
 
 } // namespace aria2
