@@ -45,32 +45,33 @@ class Peer;
 class PeerStorage;
 class DHTGetPeersReplyMessage;
 
-class DHTPeerLookupTask:
-    public DHTAbstractNodeLookupTask<DHTGetPeersReplyMessage> {
+class DHTPeerLookupTask
+    : public DHTAbstractNodeLookupTask<DHTGetPeersReplyMessage> {
 private:
   std::map<std::string, std::string> tokenStorage_;
 
-  SharedHandle<PeerStorage> peerStorage_;
+  std::shared_ptr<PeerStorage> peerStorage_;
   uint16_t tcpPort_;
+
 public:
-  DHTPeerLookupTask
-  (const SharedHandle<DownloadContext>& downloadContext,
-   uint16_t tcpPort);
+  DHTPeerLookupTask(const std::shared_ptr<DownloadContext>& downloadContext,
+                    uint16_t tcpPort);
 
-  virtual void getNodesFromMessage
-  (std::vector<SharedHandle<DHTNode> >& nodes,
-   const DHTGetPeersReplyMessage* message);
+  virtual void
+  getNodesFromMessage(std::vector<std::shared_ptr<DHTNode>>& nodes,
+                      const DHTGetPeersReplyMessage* message) CXX11_OVERRIDE;
 
-  virtual void onReceivedInternal(const DHTGetPeersReplyMessage* message);
+  virtual void
+  onReceivedInternal(const DHTGetPeersReplyMessage* message) CXX11_OVERRIDE;
 
-  virtual SharedHandle<DHTMessage> createMessage
-  (const SharedHandle<DHTNode>& remoteNode);
+  virtual std::unique_ptr<DHTMessage>
+  createMessage(const std::shared_ptr<DHTNode>& remoteNode) CXX11_OVERRIDE;
 
-  virtual SharedHandle<DHTMessageCallback> createCallback();
+  virtual std::unique_ptr<DHTMessageCallback> createCallback() CXX11_OVERRIDE;
 
-  virtual void onFinish();
+  virtual void onFinish() CXX11_OVERRIDE;
 
-  void setPeerStorage(const SharedHandle<PeerStorage>& peerStorage);
+  void setPeerStorage(const std::shared_ptr<PeerStorage>& peerStorage);
 };
 
 } // namespace aria2
